==> connectagram_1.2.11.orig.tar.gz: connectagram-1.2.11/translations/connectagram_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Цепь</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Загрузка</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Определения</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Загружаем определение...</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Неотгаданное слово</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Определение из Wiktionary, свободного словаря</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Не найдено определения</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Невозможно соединиться с Wiktionary</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Забор</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системный язык&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите программу для того, чтобы изменения вступили в силу.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Новая игра</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Маленькое</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Среднее</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Большое</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Очень большое</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Длина слов:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Количество слов:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n буква</numerusform>
            <numerusform>%n буквы</numerusform>
            <numerusform>%n букв</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Кольца</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Очки</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Очки</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Слов</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Длина</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Лестница</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Извилистый</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Волна</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Успех</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Загрузка</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Определения</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Подсказка</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новая</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Детали</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Подсказка</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>О&amp;пределения</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Очки</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Язык приложения</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Об игре</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Выбрать игру</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Номер игры:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Невозможно начать запрашиваемую игру.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Об игре</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Игра по расшифровыванию слов</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Копирайт &amp;copy; 2009-%1, Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Выпущено под лицензией &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Определения с сайта &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Шаблон:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Продолжить</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.3.orig.tar.gz: connectagram-1.3.3/translations/connectagram_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Цепь</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Загрузка</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Забор</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Выберите язык приложения:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Системный язык&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Пожалуйста, перезапустите программу для того, чтобы изменения вступили в силу.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Новая игра</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Маленькое</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Среднее</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Большое</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Очень большое</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Язык:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Длина слов:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Количество слов:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n буква</numerusform>
            <numerusform>%n буквы</numerusform>
            <numerusform>%n букв</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Кольца</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Очки</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Слов</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Длина</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Лестница</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Извилистый</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Волна</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Успех</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Загрузка</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Определения</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Подсказка</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Новая</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Выбрать...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Детали</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Подсказка</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>О&amp;пределения</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Язык приложения</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Об игре</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Выбрать игру</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Номер игры:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Извините</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Невозможно начать запрашиваемую игру.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Об игре</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Игра по расшифровыванию слов</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Копирайт &amp;copy; 2009-%1, Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Выпущено под лицензией &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Определения с сайта &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Детали</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Шаблон:</translation>
    </message>
</context>
</TS>
